changeset 28826:61a23a9a57af

Small doc fixes from Pavel Janic.
author Dave Love <fx@gnu.org>
date Sun, 07 May 2000 19:08:40 +0000
parents 58655a99714b
children f100ab01a769
files lisp/time.el
diffstat 1 files changed, 4 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/time.el	Fri May 05 20:01:01 2000 +0000
+++ b/lisp/time.el	Sun May 07 19:08:40 2000 +0000
@@ -1,4 +1,4 @@
 ;;; time.el --- display time and load in mode line of Emacs.
 
 ;; Copyright (C) 1985, 86, 87, 93, 94, 96, 2000 Free Software Foundation, Inc.
 
@@ -144,12 +144,12 @@
 
 (defvar display-time-mail-icon
   (find-image '((:type xbm :file "letter.xbm" :ascent 100)))
-  "Image specification to offer as the mail indictor on a grephic
+  "Image specification to offer as the mail indicator on a graphic
 display.  See `display-time-use-mail-icon' and
 `display-time-mail-face'.")
 
 (defcustom display-time-use-mail-icon nil
-  "Non-nil means use an icon as the mail indictor on a grephic display.
+  "Non-nil means use an icon as the mail indicator on a graphic display.
 Otherwise use the string \"Mail\".  The icon may consume less of the
 mode line.  It is specified by `display-time-mail-icon'."
   :group 'display-time
@@ -240,7 +240,7 @@
 	 (time (current-time-string now))
          (load (condition-case ()
                    (if (zerop (car (load-average))) ""
-		     ;; The load average number is myterious, so
+		     ;; The load average number is mysterious, so
 		     ;; propvide some help.
                      (let ((str (format " %03d" (car (load-average)))))
 		       (propertize
@@ -1,4 +1,4 @@
-;;; time.el --- display time and load in mode line of Emacs.
+;;; time.el --- display time, load and mail indicator in mode line of Emacs.
 
 ;; Copyright (C) 1985, 86, 87, 93, 94, 96, 2000 Free Software Foundation, Inc.